@@ -15,7 +15,7 @@ from invoke import Collection  # noqa, re-export
 from fh_fablib.extract_js_gettext_strings import generate_strings
 
 
-__version__ = "1.0.20211029"
+__version__ = "1.0.20211124"
 
 
 # I don't care, in this context.
@@ -87,7 +87,8 @@ class Config:
             setattr(self, key, value)
 
         os.chdir(self.base)
-        pre_commit_hook()
+
+        # TODO: check/add hook on every config initialization
 
     def __getattr__(self, key):
         environments = getattr(self, "environments", None)
@@ -124,15 +125,6 @@ class Connection(Connection):
         super().__init__(*args, **kwargs)
 
 
-def pre_commit_hook(*, force=False):
-    """Install the pre-commit hook running coding style checks"""
-    path = config.base / ".git" / "hooks" / "pre-commit"
-    if not path.exists() or force:
-        with path.open("w") as hook:
-            hook.write("#!/bin/sh\nfl check\n")
-        path.chmod(0o755)
-
-
 def _random_string(length, *, chars=None):
     """Returns a random string; mostly used to generate passwords and
     the contents of SECRET_KEY"""
@@ -173,8 +165,24 @@ for job in $(jobs -p); do wait $job; done
 
 @task
 def hook(ctx):
-    """Install the pre-commit hook"""
-    pre_commit_hook(force=True)
+    """
+    Add default pre-commit configuration and install hook running coding style checks
+    """
+    # shutil.copy(
+    #     Path(__file__).parent / "pre-commit-defaults.yaml",
+    #     config.base / ".pre-commit-config.yaml"
+    # )
+
+    defaults = Path(__file__).parent / "pre-commit-defaults.yaml"
+    pre_commit_config = config.base / ".pre-commit-config.yaml"
+    pre_commit_config.write_text(
+        defaults.read_text().replace(
+            "###FRONTEND_STATIC_PATTERN###",
+            f"{config.app}/static/.*$"
+        )
+    )
+
+    run(ctx, "pre-commit install -f")
 
 
 @task(auto_shortflags=False)
@@ -670,14 +678,17 @@ def fetch(ctx):
     run(ctx, f"git fetch {config.remote}")
 
 
+# legacy
 def _check_flake8(ctx):
     run(ctx, "pipx run flake8 .")
 
 
+# legacy
 def _check_django(ctx):
     run(ctx, "venv/bin/python manage.py check")
 
 
+# legacy
 def _check_prettier(ctx):
     run(
         ctx,
@@ -686,10 +697,12 @@ def _check_prettier(ctx):
     )
 
 
+# legacy
 def _check_eslint(ctx):
     run(ctx, f'yarn run eslint "*.js" {config.app}/static')
 
 
+# legacy
 def _check_large_files(ctx, *, limit=500000):
     out = run(
         ctx, "git diff-index --cached --name-only --diff-filter=AMT HEAD", hide=True
@@ -719,12 +732,8 @@ def _check_no_uncommitted_changes(ctx):
 
 @task
 def check(ctx):
-    """Check the coding style"""
-    _check_flake8(ctx)
-    _check_django(ctx)
-    _check_prettier(ctx)
-    _check_eslint(ctx)
-    _check_large_files(ctx)
+    """Check the coding style of staged files"""
+    run(ctx, "pre-commit run")
 
 
 def _fmt_prettier(ctx):
@@ -768,7 +777,7 @@ def fmt(ctx):
     _fmt_pyupgrade(ctx)
     _fmt_black(ctx)
     _fmt_isort(ctx)
-    _fmt_djlint(ctx)
+    # _fmt_djlint(ctx)
     _fmt_prettier(ctx)
 
 
